==> metview_5.14.1.orig.tar.xz: metview-5.14.1/metview/src/Desktop/TemporaryObject.h <==
/***************************** LICENSE START ***********************************

 Copyright 2012 ECMWF and INPE. This software is distributed under the terms
 of the Apache License version 2.0. In applying this license, ECMWF does not
 waive the privileges and immunities granted to it by virtue of its status as
 an Intergovernmental Organization or submit itself to any jurisdiction.

 ***************************** LICENSE END *************************************/

#ifndef TemporaryObject_H
#define TemporaryObject_H

#include "IconObject.h"
#include "Request.h"

#include <string>
using std::string;

class TemporaryObject : public IconObject
{
public:
    TemporaryObject(IconObject*, const Request&, const IconClass* = 0);
    virtual ~TemporaryObject();

protected:
    TemporaryObject(const TemporaryObject&);
    TemporaryObject& operator=(const TemporaryObject&);

    virtual void createFiles();
    //virtual Log& log();
    virtual Request request() const;
    virtual void request(const Request&);
    virtual string fullName() const;
    virtual Path path() const;
    // Different implementation of the path() if used by a
    // ShellTask.
    // For TemporaryObject Objects, it will return the PATH of the attached request, (if it exists)
    // This is done to enable the visualisation of the MAGML Objects
    // without possible side effects!
    virtual Path pathForShellTask() const;
    virtual Path dotPath() const;
    virtual Folder* parent() const;

    virtual bool rename(const string&);
    virtual bool renamable() const;
    virtual bool temporary() const;

    virtual Folder* embeddedFolder(const string& n, bool) const;
    virtual Path embeddedPath() const;
    virtual Folder* embeddedFolder(bool) const;

    virtual string relativeName(IconObject*) const;
    virtual string makeFullName(const string&) const;

private:
    IconObjectH ref_;
    Request request_;
};

inline void destroy(TemporaryObject**) {}

// If persistent, uncomment, otherwise remove
//#ifdef _ODI_OSSG_
//OS_MARK_SCHEMA_TYPE(TemporaryObject);
//#endif

#endif

==> metview_5.17.4.orig.tar.xz: metview-5.17.4/metview/src/Desktop/TemporaryObject.h <==
/***************************** LICENSE START ***********************************

 Copyright 2012 ECMWF and INPE. This software is distributed under the terms
 of the Apache License version 2.0. In applying this license, ECMWF does not
 waive the privileges and immunities granted to it by virtue of its status as
 an Intergovernmental Organization or submit itself to any jurisdiction.

 ***************************** LICENSE END *************************************/

#pragma once

#include <string>

#include "IconObject.h"
#include "Request.h"

class TemporaryObject : public IconObject
{
public:
    TemporaryObject(IconObject*, const Request&, const IconClass* = 0);
    virtual ~TemporaryObject();

protected:
    TemporaryObject(const TemporaryObject&);
    TemporaryObject& operator=(const TemporaryObject&);

    void createFiles() override;
    //virtual Log& log();
    Request request() const override;
    void setRequest(const Request&) override;
    std::string fullName() const override;
    Path path() const override;
    // Different implementation of the path() if used by a
    // ShellTask.
    // For TemporaryObject Objects, it will return the PATH of the attached request, (if it exists)
    // This is done to enable the visualisation of the MAGML Objects
    // without possible side effects!
    Path pathForShellTask() const override;
    Path dotPath() const override;
    Folder* parent() const override;

    bool rename(const std::string&) override;
    bool renamable() const override;
    bool temporary() const override;

    Folder* embeddedFolder(const std::string& n, bool) const override;
    Path embeddedPath() const override;
    Folder* embeddedFolder(bool) const override;

    std::string relativeName(IconObject*) const override;
    std::string makeFullName(const std::string&) const override;

    bool storedAsRequestFile() const  override {return true;}

private:
    IconObjectH ref_;
    Request request_;
};

inline void destroy(TemporaryObject**) {}

// If persistent, uncomment, otherwise remove
//#ifdef _ODI_OSSG_
//OS_MARK_SCHEMA_TYPE(TemporaryObject);
//#endif
